(function () {   
    let touch = isTouch();

    function isTouch() {
        return 'ontouchstart' in document;
    };

    window.modalControl = function () {

        let startX,
            endX,
            anchor;

        const arrayOpened = [];

        const numericSwipe = 200;

        const dataStickyHide = 'data-sticky-hide';
        const attrLink = 'data-modal-link';
        const attrCover = 'data-modal-cover';
        const attrScroll = 'data-modal-scroll';
        const attrClose = 'data-modal-inner-close';

        closeSwipe();

        document.addEventListener('keyup', handlerKeyup);
        document.addEventListener('click', handlerClick);

        function handlerClick(event) {
            if (event.target.closest('[' + attrLink + ']')) {
                let attrNode = event.target.closest('[' + attrLink + ']').getAttribute(attrLink);
                anchor = document.querySelector(attrNode);
                modalOpen();                
            } else if (event.target.hasAttribute(attrCover) || event.target.hasAttribute(attrClose)) {
                modalClose();
            }
        };

        function handlerKeyup(event) {
            if (event.keyCode === 27) modalClose();
        };

        function modalOpen() {
            anchor.setAttribute(attrCover, 'enabled');
            if (arrayOpened !== 0) !touch ? document.body.setAttribute(attrScroll, 'disabled') : disabledTouchScroll();
            arrayOpened.push(anchor);
        };

        function modalClose() {
            let last = arrayOpened[arrayOpened.length - 1];
            last.setAttribute(attrCover, 'disabled');
            arrayOpened.pop();
            if (arrayOpened.length === 0) {
                if (!touch) {
                    document.body.setAttribute(attrScroll, 'enabled');
                } else {
                    enabledTouchScroll();
                }
            }
        };

        function disabledTouchScroll() {
            const documentOffset = window.pageYOffset;
            document.body.style.position = 'fixed';
            document.body.style.top = -documentOffset + 'px';
        };

        function enabledTouchScroll() {
            document.body.style.position = 'static';
            window.scrollTo(0, -parseInt(getComputedStyle(document.body)['top']));
            document.body.style.top = 'auto';
        };

        function closeSwipe() {
            document.addEventListener('touchstart', touchHandler);
            document.addEventListener('touchend', touchHandler);
        };

        function touchHandler(event) {
            let touchObj;
            const target = event.target;
            const hasParent = target.closest('[' + attrCover + ']');
            if (event.type === 'touchstart') {
                touchObj = event.changedTouches[0];
                startX = parseInt(touchObj.clientX);
            } else if (event.type === 'touchend') {
                touchObj = event.changedTouches[0];
                endX = parseInt(touchObj.clientX);
                if ((startX - endX) > numericSwipe || (endX - startX) > numericSwipe) {
                    if (arrayOpened.length !== 0) {
                        modalClose();
                    }
                }
            }
        };

    };

})();    


modalControl();